@@ -4,25 +4,66 @@ from datetime import datetime
 
 
 class FieldType(Enum):
+    """コンテンツのフィールド種別"""
+
     CONTENT_ID = "contentId"
+    """コンテンツID
+    https://nico.ms/ の後に連結することでコンテンツへのURLになります
+    """
+
     TITLE = "title"
+    """タイトル"""
+
     DESCRIPTION = "description"
+    """コンテンツの説明文"""
+
     USER_ID = "userId"
+    """ユーザー投稿動画の場合、投稿者のユーザーID"""
+
     CHANNEL_ID = "channelId"
+    """	チャンネル動画の場合、チャンネルID"""
+
     VIEW_COUNTER = "viewCounter"
+    """再生数"""
+
     MYLIST_COUNTER = "mylistCounter"
+    """マイリスト数またはお気に入り数"""
+
     LIKE_COUNTER = "likeCounter"
+    """いいね！数"""
+
     LENGTH_SECONDS = "lengthSeconds"
+    """再生時間(秒)"""
+
     THUMBNAIL_URL = "thumbnailUrl"
+    """サムネイルのURL"""
+
     START_TIME = "startTime"
+    """コンテンツの投稿時間"""
+
     LAST_RES_BODY = "lastResBody"
+    """最新のコメント"""
+
     COMMENT_COUNTER = "commentCounter"
+    """コメント数"""
+
     LAST_COMMENT_TIME = "lastCommentTime"
+    """最終コメント時間"""
+
     CATEGORY_TAGS = "categoryTags"
+    """カテゴリタグ"""
+
     TAGS = "tags"
+    """タグ(空白区切り)"""
+
     TAGS_EXACT = "tagsExact"
+    """タグ完全一致(空白区切り)"""
+
     GENRE = "genre"
+    """ジャンル"""
+
     GENRE_KEYWORD = "genre.keyword"
+    """ジャンル完全一致"""
 
 
 DEFAULT_RETRY = 3
@@ -30,8 +71,6 @@ DEFAULT_RETRY = 3
 END_POINT_URL_V2 = (
     "https://api.search.nicovideo.jp/api/v2/snapshot/video/contents/search"
 )
-END_POINT_URL_NVV3 = "https://nvapi.nicovideo.jp/v3/"
-END_POINT_URL_NVV2 = "https://nvapi.nicovideo.jp/v2/"
 END_POINT_URL_VIDEO = "https://www.nicovideo.jp/watch/"
 END_POINT_URL_V2_VERSION = "https://api.search.nicovideo.jp/api/v2/snapshot/version"
 
@@ -58,10 +97,6 @@ target_types = [
 ]
 
 
-class SortKeyType(Enum):
-    REGISTERED_AT = "registeredAt"
-
-
 MatchValue: TypeAlias = Union[List[str], List[int], List[datetime]]
 RangeLiteral: TypeAlias = Literal["gt", "gte", "lt", "lte"]
 RangeValue: TypeAlias = Union[
@@ -70,5 +105,6 @@ RangeValue: TypeAlias = Union[
 MatchDict: TypeAlias = Dict[FieldType, MatchValue]
 RangeDict: TypeAlias = Dict[FieldType, RangeValue]
 CombinedDict: TypeAlias = Dict[FieldType, Union[MatchValue, RangeValue]]
+
 JSON_LITERAL: TypeAlias = str | int | float | bool | None
 JSON: TypeAlias = JSON_LITERAL | Dict[str, "JSON"] | List["JSON"]
